<?php

use Phinx\Migration\AbstractMigration;

class FormFieldType extends AbstractMigration
{
    /**
     * Change Method.
     *
     * Write your reversible migrations using this method.
     *
     * More information on writing migrations is available here:
     * http://docs.phinx.org/en/latest/migrations.html#the-abstractmigration-class
     *
     * The following commands can be used in this method and Phinx will
     * automatically reverse them when rolling back:
     *
     *    createTable
     *    renameTable
     *    addColumn
     *    renameColumn
     *    addIndex
     *    addForeignKey
     *
     * Remember to call "create()" or "update()" and NOT "save()" when working
     * with the Table class.
     */
    public function change()
    {
        $this->table('form_field_type', ['id' => 'form_field_type_id'])
            ->addColumn('form_field_type_libelle', 'string')
            ->create()
        ;

        $this->table('form_field_type')
            ->insert([
                [
                    'form_field_type_id' => 1,
                    'form_field_type_libelle' => 'Text'
                ],
                [
                    'form_field_type_id' => 2,
                    'form_field_type_libelle' => 'Dropdown'
                ],
                [
                    'form_field_type_id' => 3,
                    'form_field_type_libelle' => 'Radio Buttons'
                ],
                [
                    'form_field_type_id' => 4,
                    'form_field_type_libelle' => 'Checkbox'
                ],
            ])
            ->saveData()
        ;

        $this->table('form_field')
            ->addColumn('form_field_type_id', 'integer', ['default' => 1])
            ->addForeignKey(
                'form_field_type_id',
                'form_field_type',
                'form_field_type_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->update()
        ;

        $this->table('form_field_option', ['id' => 'form_field_option_id'])
            ->addColumn('form_field_id', 'integer')
            ->addColumn('form_field_option_value', 'string')
            ->addForeignKey(
                'form_field_id',
                'form_field',
                'form_field_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->create()
        ;

        $this->table('form_field_option_nom', ['id' => 'form_field_option_nom_id'])
            ->addColumn('form_field_option_nom_nom', 'string')
            ->addColumn('form_field_option_id', 'integer')
            ->addColumn('langue_id', 'integer')
            ->addForeignKey(
                'langue_id',
                'langue',
                'langue_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addForeignKey(
                'form_field_option_id',
                'form_field_option',
                'form_field_option_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_field_option_id', 'langue_id'], ['unique' => true])
            ->create()
        ;

        $this->table('form_field_response')
            ->addColumn('form_field_option_id', 'integer', ['null' => true])
            ->addForeignKey(
                'form_field_option_id',
                'form_field_option',
                'form_field_option_id',
                ['delete' => 'CASCADE', 'update' => 'CASCADE']
            )
            ->addIndex(['form_response_id', 'form_field_id', 'form_field_option_id'])
            ->update()
        ;
    }
}
