<?php
/**
 * Created by PhpStorm.
 * User: gabriel
 * Date: 24/05/18
 * Time: 13:09
 */

namespace CustomForm\Service;


use CustomForm\Model\Form as FormModel;
use CustomForm\Model\FormField;
use CustomForm\Service\Component\Field;
use CustomForm\Service\Component\Form;
use Form\Constraint\Mail;
use Form\Constraint\NotBlank;
use Form\Constraint\Phone;

class FormFactory
{

    /**
     * @var FormField $formFieldRepo
     */
    protected $formFieldRepo;

    public function __construct(FormField $formField)
    {
        $this->setFormFieldRepo($formField);
    }

    /**
     * Takes a loaded Form entity, and returns a Form object that can be used for displaying
     * and
     *
     * @param FormModel $formModel
     * @return Form
     */
    public function make(FormModel $formModel)
    {
        $form = new Form($formModel);
        $fields = $this->getFormFieldRepo()->get(['form_id' => $formModel->getFormId()]);
        array_walk($fields, function (array &$arrField) use ($form) {
            $formFieldModel = new FormField();
            $formFieldModel->hydrate($arrField);
            $field = new Field("custom_field_{$formFieldModel->getFormFieldId()}", $formFieldModel);
            $arrConstraints = $formFieldModel->fetchConstraints();
            array_walk($arrConstraints, function (array $arrConstraint) use ($field) {
                $mapping = [
                    FormField::CONSTRAINT_NOT_BLANK_ID => new NotBlank(),
                    FormField::CONSTRAINT_EMAIL_ID => new Mail(),
                    FormField::CONSTRAINT_FRENCH_PHONE_ID => new Phone(),
                ];
                $field->addConstraints(
                    $arrConstraint['form_field_constraint_id'],
                    $mapping[$arrConstraint['form_constraint_id']],
                    "Ce champs est invalide"
                );
            });
            $field->setOptions($this->getFormFieldRepo()->fetchOptions());
            $form->add($field);
        });

        return $form;
    }

    /**
     * @return FormField
     */
    public function getFormFieldRepo()
    {
        return $this->formFieldRepo;
    }

    /**
     * @param FormField $formFieldRepo
     * @return FormFactory
     */
    public function setFormFieldRepo($formFieldRepo)
    {
        $this->formFieldRepo = $formFieldRepo;
        return $this;
    }


}